@@ -8,8 +8,8 @@
     stop("'node' must be character of length 1")
   if(!is.character(stem) || length(stem)!=1)
     stop("'stem' must be character of length 1")
-  stem <- if(dirname(stem) == ".") 
-    file.path(getwd(), basename(stem))
+  if(dirname(stem) == ".") 
+    stem <- file.path(getwd(), basename(stem))
 
   oldBeg <- samplesGetBeg()
   oldEnd <- samplesGetEnd()
@@ -33,7 +33,6 @@
   command <- paste("SamplesEmbed.SetVariable(", sQuote(node),
     ");SamplesEmbed.StatsGuard;", "SamplesEmbed.CODA(", 
     sQuote(stem), ")")
-
   .C("CmdInterpreter", as.character(command), nchar(command), 
     integer(1), PACKAGE="BRugs")
   buffer()
