@@ -5,7 +5,7 @@ help.BRugs <- function(browser = getOption("browser"))
     if (!file.exists(a)) 
         stop("I can't find the html help")
     a <- chartr("/", "\\", a)
-    cat("If nothing happens, you should open `", a, "' yourself\n")
+    message("If nothing happens, you should open `", a, "' yourself")
     browseURL(a, browser = browser)
     invisible("")
 }
@@ -17,7 +17,7 @@ help.WinBUGS <- function(browser = getOption("browser"))
     if (!file.exists(a)) 
         stop("I can't find the html help")
     a <- chartr("/", "\\", a)
-    cat("If nothing happens, you should open `", a, "' yourself\n")
+    message("If nothing happens, you should open `", a, "' yourself")
     browseURL(a, browser = browser)
     invisible("")
 }
